@@ -1,8 +1,13 @@
-from typing import Optional, List, BinaryIO
+from typing import BinaryIO, List, Optional
+from urllib.parse import urlencode
+
+import httpx
 
 from . import types
 
-import httpx
+ENDPOINT_TRANSCRIPT = "/v2/transcript"
+ENDPOINT_UPLOAD = "/v2/upload"
+ENDPOINT_LEMUR = "/lemur/v3/generate"
 
 
 def _get_error_message(response: httpx.Response) -> str:
@@ -27,13 +32,12 @@ def create_transcript(
     request: types.TranscriptRequest,
 ) -> types.TranscriptResponse:
     response = client.post(
-        "/transcript",
+        ENDPOINT_TRANSCRIPT,
         json=request.dict(
             exclude_none=True,
             by_alias=True,
         ),
     )
-
     if response.status_code != httpx.codes.ok:
         raise types.TranscriptError(
             f"failed to transcript url {request.audio_url}: {_get_error_message(response)}"
@@ -47,7 +51,7 @@ def get_transcript(
     transcript_id: str,
 ) -> types.TranscriptResponse:
     response = client.get(
-        f"/transcript/{transcript_id}",
+        f"{ENDPOINT_TRANSCRIPT}/{transcript_id}",
     )
 
     if response.status_code != httpx.codes.ok:
@@ -73,7 +77,7 @@ def upload_file(
     """
 
     response = client.post(
-        "/upload",
+        ENDPOINT_UPLOAD,
         content=audio_file,
     )
 
@@ -98,7 +102,7 @@ def export_subtitles_srt(
         }
 
     response = client.get(
-        f"/transcript/{transcript_id}/srt",
+        f"{ENDPOINT_TRANSCRIPT}/{transcript_id}/srt",
         params=params,
     )
 
@@ -123,7 +127,7 @@ def export_subtitles_vtt(
         }
 
     response = client.get(
-        f"/transcript/{transcript_id}/vtt",
+        f"{ENDPOINT_TRANSCRIPT}/{transcript_id}/vtt",
         params=params,
     )
 
@@ -141,10 +145,12 @@ def word_search(
     words: List[str],
 ) -> types.WordSearchMatchResponse:
     response = client.get(
-        f"/transcript/{transcript_id}/word-search",
-        params={
-            "words": words,
-        },
+        f"{ENDPOINT_TRANSCRIPT}/{transcript_id}/word-search",
+        params=urlencode(
+            {
+                "words": ",".join(words),
+            }
+        ),
     )
 
     if response.status_code != httpx.codes.ok:
@@ -155,12 +161,47 @@ def word_search(
     return types.WordSearchMatchResponse.parse_obj(response.json())
 
 
+def get_redacted_audio(
+    client: httpx.Client, transcript_id: str
+) -> types.RedactedAudioResponse:
+    """
+    Retrieves the object containing the redacted audio URL for the given transcript.
+
+    Raises:
+        RedactedAudioIncompleteError: If response indicates that the redacted audio is still processing
+        RedactedAudioUnavailableError: If response indicates that the redacted audio is not available
+        TranscriptError: If we fail to get a valid response from the API at all
+
+    Returns:
+        `RedactedAudioResponse`, which contains the URL of the redacted audio
+    """
+
+    response = client.get(f"{ENDPOINT_TRANSCRIPT}/{transcript_id}/redacted-audio")
+
+    if response.status_code == httpx.codes.ACCEPTED:
+        raise types.RedactedAudioIncompleteError(
+            f"redacted audio for transcript {transcript_id} is not ready yet"
+        )
+
+    if response.status_code == httpx.codes.BAD_REQUEST:
+        raise types.RedactedAudioExpiredError(
+            f"redacted audio for transcript {transcript_id} is no longer available"
+        )
+
+    if response.status_code != httpx.codes.OK:
+        raise types.TranscriptError(
+            f"failed to retrieve redacted audio for transcript {transcript_id}: {_get_error_message(response)}"
+        )
+
+    return types.RedactedAudioResponse.parse_obj(response.json())
+
+
 def get_sentences(
     client: httpx.Client,
     transcript_id: str,
 ) -> types.SentencesResponse:
     response = client.get(
-        f"/transcript/{transcript_id}/sentences",
+        f"{ENDPOINT_TRANSCRIPT}/{transcript_id}/sentences",
     )
 
     if response.status_code != httpx.codes.ok:
@@ -176,7 +217,7 @@ def get_paragraphs(
     transcript_id: str,
 ) -> types.ParagraphsResponse:
     response = client.get(
-        f"/transcript/{transcript_id}/paragraphs",
+        f"{ENDPOINT_TRANSCRIPT}/{transcript_id}/paragraphs",
     )
 
     if response.status_code != httpx.codes.ok:
@@ -193,7 +234,7 @@ def lemur_question(
     http_timeout: Optional[float],
 ) -> types.LemurQuestionResponse:
     response = client.post(
-        "/generate/question-answer",
+        f"{ENDPOINT_LEMUR}/question-answer",
         json=request.dict(
             exclude_none=True,
         ),
@@ -214,7 +255,7 @@ def lemur_summarize(
     http_timeout: Optional[float],
 ) -> types.LemurSummaryResponse:
     response = client.post(
-        "/generate/summary",
+        f"{ENDPOINT_LEMUR}/summary",
         json=request.dict(
             exclude_none=True,
         ),
@@ -229,13 +270,13 @@ def lemur_summarize(
     return types.LemurSummaryResponse.parse_obj(response.json())
 
 
-def lemur_coach(
+def lemur_task(
     client: httpx.Client,
-    request: types.LemurCoachRequest,
+    request: types.LemurTaskRequest,
     http_timeout: Optional[float],
-) -> types.LemurCoachResponse:
+) -> types.LemurTaskResponse:
     response = client.post(
-        "/generate/ai-coach",
+        f"{ENDPOINT_LEMUR}/task",
         json=request.dict(
             exclude_none=True,
         ),
@@ -244,7 +285,7 @@ def lemur_coach(
 
     if response.status_code != httpx.codes.ok:
         raise types.LemurError(
-            f"failed to call Lemur AI coach: {_get_error_message(response)}"
+            f"failed to call Lemur task: {_get_error_message(response)}"
         )
 
-    return types.LemurCoachResponse.parse_obj(response.json())
+    return types.LemurTaskResponse.parse_obj(response.json())
